import http from 'k6/http'
import { check } from 'k6'

const allChecksNeedToPassTreshold = { checks: [{ threshold: 'rate==1', abortOnFail: true }] }

export const options = {
  vus: 1,
  iterations: 1,
  thresholds: allChecksNeedToPassTreshold,
}

function forQuery(query, checkFunction) {
  const response = http.post(`${__ENV.BASE_URL}`, JSON.stringify({ query }), {
    headers: { 'Content-Type': 'application/json' },
  })
  checkFunction(response)
}

export default () => {
  forQuery('query IntrospectionQuery {  __schema { types { name } }}', (response) => {
    check(response, {
      'can be introspected': (r) => r.status === 200,
    })
  })

  forQuery(`{ events(limit: 1) { data { id } } }`, (response) => {
    check(JSON.parse(response.body), {
      'returns events': (r) => Array.isArray(r.data.events.data) && r.data.events.data.length > 0,
    })
  })

  forQuery(`{ event(id: "1234") { data { id } } }`, (response) => {
    check(JSON.parse(response.body), {
      'returns event': (r) => r.data.event.data.id === '1234',
    })
  })
}
